@@ -1,14 +1,14 @@
 package Plack::App::FakeApache;
-$Plack::App::FakeApache::VERSION = '0.09';
+$Plack::App::FakeApache::VERSION = '0.1';
 use Try::Tiny;
 use strict;
 use warnings;
+use attributes;
 
 use Plack::Util;
 use Plack::Util::Accessor qw( authen_handler authz_handler response_handler handler dir_config root logger request_args request_class without_cgi);
 
 use parent qw( Plack::Component );
-use attributes;
 
 use Carp;
 use Module::Load;
@@ -35,7 +35,7 @@ sub _run_first
 
 
 	# Mangle env to cope with certain kinds of CGI brain damage.
-	unless ($self->without_cgi) {
+	if  ( $self->with_cgi) {
 		require CGI::Emulate::PSGI;
 		my $env = $fake_req->plack_request->env;
 		local %ENV = (%ENV, CGI::Emulate::PSGI->emulate_environment($env));
@@ -44,14 +44,13 @@ sub _run_first
 	}
 
     my $status = OK;
-    foreach my $handler ($self->_get_phase_handlers($phase))
-    {
+    foreach my $handler ($self->_get_phase_handlers($phase)) {
         try {
-			$status = $handler->($fake_req);
-		}
-		  catch { 
-			  die $_ unless $_ =~ /^EXIT 0$/;
-		  };
+            $status = $handler->($fake_req);
+        }
+            catch {
+                die $_ unless $_ =~ /^EXIT 0$/;
+            };
         last if $status != DECLINED;
     }
     return (defined($status) and $status != DECLINED) ? $status : $fallback_status; # mod_perl seems to do this if all handlers decline
@@ -83,8 +82,7 @@ sub call {
     return $fake_req->finalize;
 }
 
-sub _run_handlers
-{
+sub _run_handlers {
     my $self = shift;
     my $fake_req = shift;
     my $status;
@@ -116,8 +114,7 @@ sub prepare_app {
 
     $self->response_handler($self->response_handler || $self->handler);
 
-    foreach my $accessor ( qw(authen_handler authz_handler response_handler) )
-    {
+    foreach my $accessor ( qw(authen_handler authz_handler response_handler) ) {
         my $handlers = $self->$accessor or next;
         my @handlers = ref($handlers) eq 'ARRAY' ? @{$handlers} : ($handlers);
         @handlers = map({ $self->_massage_handler($_) } @handlers);
@@ -129,26 +126,25 @@ sub prepare_app {
     # Workaround for mod_perl handlers doing CGI->new($r). CGI doesn't
     # know our fake request class, so we hijack CGI->new() and explicitly
     # pass the request query string instead...
-	unless ($self->without_cgi) {
-		my $new = CGI->can('new');
-		no warnings qw(redefine);
-		*CGI::new = sub {
-			my $request_class = $self->request_class || 'Plack::App::FakeApache::Request';
-
-			if (blessed($_[1]) and $_[1]->isa($request_class)) {
-				return $new->(CGI => $_[1]->env->{QUERY_STRING} || $_[1]->plack_request->content);
-			}
-			return $new->(@_);
-		};
-	}
-	else { 
-		my $new = CGI->can('new');
-		no warnings qw/redefine/;
-		*CGI::new = sub {
-			warn "CALLING CGI->new\n";
-			return $new(@_);
-		};
-	}
+    if ($self->with_cgi) {
+        my $new = CGI->can('new');
+        no warnings qw(redefine);
+        *CGI::new = sub {
+            my $request_class = $self->request_class || 'Plack::App::FakeApache::Request';
+            if (blessed($_[1]) and $_[1]->isa($request_class)) {
+                return $new->(CGI => $_[1]->env->{QUERY_STRING} || $_[1]->plack_request->content);
+            }
+            return $new->(@_);
+        };
+    }
+    else { # we probably want CGI.pm to complain it's being called if we get here
+        my $new = CGI->can('new');
+        no warnings qw/redefine/;
+        *CGI::new = sub {
+            warn "CALLING CGI->new\n";
+            return $new(@_);
+        };
+    }
     return;
 }
 
@@ -175,8 +171,12 @@ sub _massage_handler
     return $handler;
 }
 
+sub with_cgi {
+    return ! $_[0]->without_cgi
+}
+
 package Plack::App::FakeApache::Tie;
-$Plack::App::FakeApache::Tie::VERSION = '0.09';
+$Plack::App::FakeApache::Tie::VERSION = '0.1';
 sub TIEHANDLE {
     my $class = shift;
     my $r = shift;
@@ -210,14 +210,11 @@ a PSGI application
 
 =head1 NOTICE
 
-This is Proof of Concept code originating in the mocking code developed to
-test an internal very non-trivial mod_perl2 application. Features have been
-added on a need to have basis.
-
-This code has been extended to make a different non-trivial mod_perl
-app work under plack too.  If you need to use this module for serious
-work you will almost certainly need to read and modify the source.
-Contributions welcomed.
+While this code is labeled "Proof of Concept" it's been around a while now,
+and seems stable.  However the major problem with mod_perl as a web
+application development environment is that there are too many ways to do
+it, and this API only handles a common subset of functionality.  Thus you
+may have to get your hands dirty in the code for serious use. Contributions welcomed.
 
 =head1 CONFIGURATION
 
@@ -239,18 +236,23 @@ conventions.
 
 =item request_class
 
-If you want to subclass Plack::App::FakeApache::Request do so here.
-Make sure that your subclass inherits from
-Plack::App::FakeApache::Request (duh).  This is for use in situations
-where you've subclasssed Apache2::Request and want to make it work
-under PSGI.
+If you want to subclass Plack::App::FakeApache::Request do so here.  Make
+sure that your subclass inherits from Plack::App::FakeApache::Request
+(duh). You may want this if you need to handle subclasses of your apache
+request object, or to cover some kinds of functionality not exposed by this
+module.
 
 =item without_cgi
+=item with_cgi
 
-CGI.pm does bad things to STDIN and ENV.  If your mod_perl app uses
-these, but your're transitioning away from CGI.pm (e.g. in order to
-support POST parameters with your app running under L<Plack::Client>),
-then you can selectively set this to false. For example:
+CGI.pm does bad things to STDIN and ENV.  This attribute is a helper in
+order to help move away from it (as in, once CGI.pm is properly expurgated
+your app will run ok with C<whitout_cgi> switched on.
+
+In the interestes of naming things, while construction is handled by
+without_cgi, the code itself looks for its negation C<with_cgi> when
+applying the conditional logic in order to avoid cumbersome
+double-negatives.
 
   my $app = Plack::App::FakeApache->new({ 
       handler       => 'MyApp',
