@@ -1,6 +1,7 @@
 package Plack::App::FakeApache::Connection;
-$Plack::App::FakeApache::Connection::VERSION = '0.09';
+$Plack::App::FakeApache::Connection::VERSION = '0.1';
 use Moo;
+use namespace::autoclean;
 use Types::Standard qw/Str/;
 use Plack::App::FakeApache::Log;
 
@@ -15,11 +16,9 @@ has log => (
     handles => [qw(log_error log_serror warn)],
 );
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
-
 1;
 
+__END__
 =head1 NAME
 
 Plack::App::FakeApache::Request::Connection - mock Apache::Connection for Plack
