@@ -1,6 +1,7 @@
 package Plack::App::FakeApache::Request;
-$Plack::App::FakeApache::Request::VERSION = '0.09';
+$Plack::App::FakeApache::Request::VERSION = '0.1';
 use Moo;
+use namespace::autoclean;
 use MooX::HandlesVia;
 use Types::Standard qw/HashRef Any InstanceOf Bool Str Maybe/;
 use APR::Pool;
@@ -256,7 +257,7 @@ sub read {
 
     my $request = $self->plack_request;
 
-    # Is this needed? Intrudes on a Plack::Request private methodf...
+    # Is this needed? Intrudes on a Plack::Request private method...
     unless ($request->env->{'psgix.input.buffered'}) {
         $request->_parse_request_body;
 
@@ -292,7 +293,6 @@ sub write {
     my $output = substr $buffer, $offset // 0, $length // length $buffer;
 
     $self->_add_content($output);
-    
     return length $output;
 }
 
@@ -306,14 +306,12 @@ sub rflush {
     1;
 }
 
-sub uri
-{
+sub uri {
     my $self = shift;
     return $self->plack_request->uri->path;
 }
 
-sub construct_url
-{
+sub construct_url {
     my $self = shift;
     my $path = shift;
     my $uri  = URI->new($self->plack_request->uri);
@@ -321,7 +319,4 @@ sub construct_url
     return $uri->as_string;
 }
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
-
 1;
