@@ -1,7 +1,7 @@
 package Plack::App::FakeApache::Server;
-$Plack::App::FakeApache::Server::VERSION = '0.09';
+$Plack::App::FakeApache::Server::VERSION = '0.1';
 use Moo;
-
+use namespace::autoclean;
 use Plack::App::FakeApache::Log;
 
 has log => (
@@ -10,7 +10,4 @@ has log => (
     handles => [ qw(log_error log_serror warn) ],
 );
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
-
 1;
